# pyfost.gestion_studio

[![PyPI - Version](https://img.shields.io/pypi/v/pyfost-gestion-studio.svg)](https://pypi.org/project/pyfost-gestion-studio)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyfost-gestion-studio.svg)](https://pypi.org/project/pyfost-gestion-studio)

[Fost](fost.studio) Studio Management Tools
-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install pyfost.gestion-studio
```

## License

`pyfost.gestion-studio` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.
